@@ -19,14 +19,17 @@ foreach my $file (@ARGV) {
     my @l = map {
         my $orig = $_;
 
-        s/kDebug\(\)/qDebug\(\)/;
-        s/kdDebug\(\)/qDebug\(\)/;
-        s/kWarning\(\)/qWarning\(\)/;
-        s/kdWarning\(\)/qWarning\(\)/;
-        s/kError\(\)/qCritical\(\)/;
-        s/kFatal\(\)/qFatal\(\)/;
+        s/kDebug\s*\(\s*\)/\/\/qDebug\(\)/;
+        s/kdDebug\s*\(\s*\)/\/\/qDebug\(\)/;
+        s/kWarning\s*\(\s*\)/qWarning\(\)/;
+        s/kdWarning\s*\(\s*\)/qWarning\(\)/;
+        s/kError\s*\(\s*\)/qCritical\(\)/;
+        s/kFatal\s*\(\s*\)/qFatal\(\)/;
         s/k_funcinfo/Q_FUNC_INFO/;
-        s/kdebug\.h/qdebug\.h/;
+
+        s/\<kdebug\.h>/\<QDebug>/ if (/#include/);
+        s/\<KDebug\>/\<QDebug>/ if (/#include/);
+        s/\"kdebug\.h"/\<QDebug>/ if (/#include/);
 
         #s/\<\< endl//; # old stuff
 
@@ -38,6 +41,7 @@ foreach my $file (@ARGV) {
         open (my $OUT, ">", $file);
         print $OUT @l;
         close ($OUT);
+        functionUtilkde::addIncludeInFile($file, "QDebug");
     }
 }
 
