@@ -23,7 +23,8 @@ my %otherResource = (
    "icon" => "icons",
    "locale" => "locale",
    "wallpaper" => "wallpapers",
-   "xdgdata-mime" => "mime"
+   "xdgdata-mime" => "mime",
+   "sound" => "sound"
 );
 
 my %xdgconfResource = (
@@ -59,11 +60,15 @@ foreach my $file (@ARGV) {
         s/KGlobal::dirs\(\)->findResource\b/KStandardDirs::locate/;
         s/KGlobal::dirs\(\)->locate/KStandardDirs::locate/;
         s/KGlobal::dirs\(\)->findExe/KStandardDirs::findExe/;
-        s/KGlobal::dirs\(\)->localxdgdatadir\(\)/QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('\/')/;
-        s/KGlobal::dirs\(\)->localxdgconfdir\(\)/QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + QLatin1Char('\/')/;
+        s/KGlobal::dirs\(\)->localxdgdatadir\s*\(\)/QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('\/')/;
+        s/KGlobal::dirs\(\)->localxdgconfdir\s*\(\)/QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + QLatin1Char('\/')/;
         s/KStandardDirs::locate\s*\(\s*"exe", /KStandardDirs::findExe\(/;
 
-        if (/KStandardDirs::locateLocal\(\s*\"(.*)\",\s*(.*)\s*\)/) {
+        if ( /KStandardDirs::Recursive/ ) {
+           warn "$file : we can not convert directly see https://community.kde.org/Frameworks/Porting_Notes/KStandardDirs \n";
+        }
+
+        if (/KStandardDirs::locateLocal\s*\(\s*\"(.*)\",\s*(.*)\s*\)/) {
             my ($loc, $fileName) = locationAndSubdir($1, $2);
             if (defined $loc) {
                 # prepend a slash
@@ -72,7 +77,7 @@ foreach my $file (@ARGV) {
                 } else {
                     $fileName = "QLatin1Char('\/') + " . $fileName;
                 }
-                s/KStandardDirs::locateLocal\(.*\)/QStandardPaths::writableLocation($loc) + $fileName/;
+                s/KStandardDirs::locateLocal\s*\(.*\)/QStandardPaths::writableLocation($loc) + $fileName/;
             }
         }
         if (/KStandardDirs::locate\s*\(\s*\"(.*)\",\s*(.*)\s*\)/ ||
@@ -84,14 +89,13 @@ foreach my $file (@ARGV) {
                 #print STDERR "fileName=$fileName\n";
                 my ($search, $replace);
                 if (/KStandardDirs::locate/) {
-                   $search = qr/KStandardDirs::locate/;
+                   $search = qr/KStandardDirs::locate\s*/;
                    $replace = "QStandardPaths::locate";
                 } elsif (/KGlobal::dirs\(\)->findAllResources/) {
-                   $search = qr/KGlobal::dirs\(\)->findAllResources/;
+                   $search = qr/KGlobal::dirs\(\)->findAllResources\s*/;
                    $replace = "QStandardPaths::locateAll";
                 } elsif (/KGlobal::dirs\(\)->findDirs/) {
-                   warn "found Global::dirs\(\)->findD\n";
-                   $search = qr/KGlobal::dirs\(\)->findDirs/;
+                   $search = qr/KGlobal::dirs\(\)->findDirs\s*/;
                    $replace = "QStandardPaths::locateAll";
                 }
                 if ($fileName =~ s/\/\"$/\"/ || $fileName =~ s/\/\"\)$/\"\)/) {
@@ -101,7 +105,27 @@ foreach my $file (@ARGV) {
                 }
             }
         }
+        my $regexp = qr/
+           ^(\s*)                                  # (1) Indentation
+           (.*?)                                   # (2) Possibly "Classname " (the ? means non-greedy)
+           (\w+)                                   # (3) variable name
+           \s*=\s*                                 #   assignment
+           KGlobal::dirs\(\)->findResourceDir\s*\(\s* #  KGlobal::dirs\(\)->findResourceDir\(
+           \"(.*)\"\s*,                            # (4) location
+           \s*(.*)\s*\)                            # (5) subdir
+           (.*)$                                   # (6) afterreg
+           /x; # /x Enables extended whitespace mode
+        if (my ($indent, $left, $var, $location, $subdir, $after) = $_ =~ $regexp) {
+           my ($loc, $fileName) = locationAndSubdir($location, $subdir);
+           if (defined $loc) {
+               warn "$loc, $fileName\n";
+               $_ = $indent . $left . $var . "= QStandardPaths::locate($loc, $fileName)" . $after . "\n";
+               $_ .= $indent . "$var = QFileInfo($var).absolutePath();\n";
+           }
+        }
+       
 
+ 
         if (/KStandardDirs::findExe\s*\(\s*\"(.*)\"(,\s*[^\)]*)?\s*\)/ ||
             /KStandardDirs::findExe\s*\(\s*QLatin1String\s*\(\"(.*)\"\)(,\s*[^\)]*)?\s*\)/) {
             my $exe = $1;
@@ -160,6 +184,10 @@ foreach my $file (@ARGV) {
     if (not `grep -i dirs $file | grep -v kstandarddirs\.h`) {
       functionUtilkde::removeIncludeInFile($file, "kstandarddirs.h");
     }
+    if (not `grep -i dirs $file | grep -v KStandardDirs`) {
+      functionUtilkde::removeIncludeInFile($file, "KStandardDirs");
+    }
+
     if (`grep QStandardPaths $file | grep -v '#include'`) {
       functionUtilkde::addIncludeInFile($file, "QStandardPaths");
     }
